templatetools.StringOrchestraScoreTemplate
==========================================

.. abjad-lineage:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate

.. autoclass:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.cello_count
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.contrabass_count
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.viola_count
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.violin_count
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__call__
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__eq__
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__format__
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__ne__
      ~abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.cello_count
   :noindex:

.. autoattribute:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.contrabass_count
   :noindex:

.. autoattribute:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.viola_count
   :noindex:

.. autoattribute:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.violin_count
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__call__
   :noindex:

.. automethod:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__eq__
   :noindex:

.. automethod:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__format__
   :noindex:

.. automethod:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__ne__
   :noindex:

.. automethod:: abjad.tools.templatetools.StringOrchestraScoreTemplate.StringOrchestraScoreTemplate.__repr__
   :noindex:
